@@ -187,6 +187,16 @@ def sendurl(request):
         if form.is_valid():
             model = form.save(commit=False)
             
+            category = post_values['category']
+                
+            if category.startswith('newcat-'):
+                category = category.replace('newcat-', '')
+                category, created = Category.objects.get_or_create(user=request.user,name=category)
+            else:
+                category = Category.objects.filter(user=request.user, id=category).all()
+                
+            model.category_id = category.id
+            
             image_url= model.image
             
             filename = image_url.split('/')[-1]
@@ -243,7 +253,9 @@ def send(request):
             model = form.save(commit=False)
             
             category = post_values['category']
-            if isinstance(category, string):
+                
+            if category.startswith('newcat-'):
+                category = category.replace('newcat-', '')
                 category, created = Category.objects.get_or_create(user=request.user,name=category)
             else:
                 category = Category.objects.filter(user=request.user, id=category).all()
@@ -296,6 +308,16 @@ def edit(request, post_id):
             form = PinUpdateForm(post_values, instance=post)
             if form.is_valid():
                 model = form.save(commit=False)
+                category = post_values['category']
+                
+                if category.startswith('newcat-'):
+                    category = category.replace('newcat-', '')
+                    category, created = Category.objects.get_or_create(user=request.user,name=category)
+                else:
+                    category = Category.objects.filter(user=request.user, id=category).all()
+                    
+                model.category_id = category.id
+                
                 model.save()
                 
                 form.save_m2m()
